Deployment how to — fantastico 0.4.0-b114 documentation

### Navigation

- index
- next |
- previous |
- fantastico 0.4.0-b114 documentation »
- How to articles »

# Deployment how to

In this how to we guide you to Fantastico deployment to production. Below you can find various deployment scenarios that can be used for various needs.

- Low usage (simplest scenario)
  - Setup
- Low usage AWS
  - Setup
  - Optimization
  - Setup with S3

### Navigation

- index
- next |
- previous |
- fantastico 0.4.0-b114 documentation »
- How to articles »